% Filename: Ex23_3.m
% Created: 1 July 2011

%% Example 23.3 MATLAB

clc
clear all

% Declare any needed variables
syms q_s0I q_s0II q_s0III
B = [2580 3880 3230 3230 3880 2580];
y = [165 230 200 -200 -230 -165];
e = 50;
w = 1020;
S_y = 86.8*10^3;
G = [27600 27600 27600 3*27600 27600 27600 27600 27600 27600 27600];
G_ref = 27600;

% Define the length, thickness, and cell areas provided
L = [1023 1274 2200 1270 1023 330 (y(2)-e) -(y(5)-e) (y(3)-e) -(y(4)-e)]; 
t = [1.22 1.63 2.03 1.22 1.22 1.63 2.64 2.64 2.64 2.64];
A = [265000 213000 413000];

% Calculate the modulus weighted thickness using Eq. (23.9)
t_s = t.*G/G_ref;

% Calculate the delta for each wall/cell
del = round(L./t_s);
delta_I = del(3)+sum(del(9:10));
delta_II = del(2)+del(9)+del(4)+del(7);
delta_III = del(1)+sum(del(5:8));

delta = [delta_I delta_II delta_III];
delta_I = [del(3) del(9) del(10)];
delta_II = [del(2) del(9) del(4) del(7)];
delta_III = [del(1) del(5) del(6) del(7) del(8)];

% Calculate the section properties
I_xx = sum(B.*y.^2); 
    % I_yy and I_xy not needed due to symmetry and M_y=0

% Due to symmetry and since S_x=0, Eq. (20.6) simplifies
% Calculate the base shear flows in the section using the reduced Eq. (20.6)
B_i = B.*y;
C = round(-S_y/I_xx*10^6)/(10^6);
q_12b = 0;  % Cut cell in wall 1-2
q_23b = 0;  % Cut cell in wall 2-3
q_34b = 0;  % Cut cell in wall 3-4
q_38b = round(C*B_i(3)*10)/10;
q_48b = round(C*B_i(4)*10)/10;
q_78b = q_48b + q_38b;
q_27b = round(C*B_i(2)*10)/10;
q_57b = round(C*B_i(5)*10)/10;
q_16b = round(C*B_i(1)*10)/10;
q_65b = q_16b + round(C*B_i(6)*10)/10;
q_b = [q_12b q_23b q_34b -q_78b -q_65b -q_16b q_27b q_57b q_38b -q_48b];
q_bI = [q_34b -q_38b q_48b];
q_bII = [q_23b q_38b q_78b -q_27b];
q_bIII = [q_12b -q_65b -q_16b q_27b -q_57b];

% Substitute the values of delta and q_b into Eq. (23.10) for each cell
eqI = (q_s0I*delta(1)-q_s0II*del(9)+sum(q_bI.*delta_I))/(2*A(1)*G_ref);
eqII = (-q_s0I*del(9)+q_s0II*delta(2)-q_s0III*del(7)+sum(q_bII.*delta_II))/(2*A(2)*G_ref);
eqIII = (-q_s0II*del(7)+q_s0III*delta(3)+sum(q_bIII.*delta_III))/(2*A(3)*G_ref);

% Take moments about the intersection of the x-axis and web 572 using Eq. (23.12)
L_M = [y(1) y(2) y(3) e y(5) w 0 0 L(4) L(4)];
eqIV = sum(q_b.*L_M.*L)+sum(2*A.*[q_s0I q_s0II q_s0III]);

% Simultaneously solve eqI-eqIV
[q_s0i q_s0ii q_s0iii] = solve(eqI-eqII,eqII-eqIII,eqIV,q_s0I,q_s0II,q_s0III);
q_s0i = vpa(q_s0i,2);
q_s0ii = vpa(q_s0ii,2); 
q_s0iii = vpa(q_s0iii,2);

% Calculate the shear flows using q_s0i, q_s0ii, and q_s0iii
q_12 = q_12b+q_s0iii;
q_23 = q_23b+q_s0ii;
q_34 = q_34b+q_s0i;
q_78 = q_78b-q_s0ii;
q_65 = q_65b-q_s0iii;
q_16 = q_16b-q_s0iii;
q_27 = q_27b+q_s0iii-q_s0ii;
q_57 = q_57b-q_s0iii;
q_38 = q_38b-q_s0i+q_s0ii;
q_48 = q_48b+q_s0i;

q = double([q_12 q_23 q_34 q_78 q_65 q_16 q_27 q_57 q_38 q_48]);
q = round(q*10)/10;

% Substitute q_s0i, q_s0ii, and q_s0iii back into any of eqI-eqIV
dtheta_dz = subs(subs(eqI,q_s0I,q_s0i),q_s0II,q_s0ii);
dtheta_dz = round(double(dtheta_dz)*10^8)/(10^8);

% Output the shear flows and angle of twist to the Command Window
disp('The shear flows (N/mm) are:')
text = '[q_12, q_23, q_34, q_78, q_65, q_16, q_27, q_57, q_38, q_48] = [';
c = length(text);
for j=1:1:10
    num = num2str(q(j));
    if j<10
        text(c+1:c+length(num)+2) = [num ', '];
        c = length(text);
    else
        text(c+1:c+length(num)+1) = [num ']'];
        disp(text)
    end
end

disp(['The rate of twist in the section = ' num2str(dtheta_dz) ' rad/mm'])

